#define _SUPPRESS_PLIB_WARNING 1
#include "plib.h"
#include "gyro.h"


int begin_gyro(l3gd20Range_t rng) {
    
    /* Set CTRL_REG1 (0x20)
   ====================================================================
   BIT  Symbol    Description                                   Default
   ---  ------    --------------------------------------------- -------
   7-6  DR1/0     Output data rate                                   00
   5-4  BW1/0     Bandwidth selection                                00
     3  PD        0 = Power-down mode, 1 = normal/sleep mode          0
     2  ZEN       Z-axis enable (0 = disabled, 1 = enabled)           1
     1  YEN       Y-axis enable (0 = disabled, 1 = enabled)           1
     0  XEN       X-axis enable (0 = disabled, 1 = enabled)           1 */
    
    /* Switch to normal mode and enable all three channels */
    writeGyroSpi(CTRL1,0x0F);
    
    range = rng;
    //determine the sensitivity (dps))
    switch(range)
    {
    case L3DS20_RANGE_250DPS:
        //250 dps - default
        writeGyroSpi(CTRL4, 0x00);
        break;
    case L3DS20_RANGE_500DPS:
        writeGyroSpi(CTRL4, 0x10);
        break;
    case L3DS20_RANGE_2000DPS:
        writeGyroSpi(CTRL4, 0x20);
        break;
    default:
        writeGyroSpi(CTRL4, 0x00);
        break;
    }
    
    //make sure the gyro is responding
    int id = debug_gyro();
    
    if (id == 215 || id == 212) {
        return 1;
    } else {
        return 0;
    }
   /* ------------------------------------------------------------------ */
}

/*
 Used only for debugging purposes to make sure the SPI channel is working
 and the gyro is acknologing*/
int debug_gyro(void) {
    UINT8 id;
    GYRO_CS = 0;
    while (TxBufFullSPI2());
    WriteSPI2(WHOAMI | 0x80); //binary OR with 10000000 (control byte) - 1 for read
    while (SPI2STATbits.SPIBUSY); // wait for it to end of transaction
    ReadSPI2();
    WriteSPI2(0xFF);
    while (SPI2STATbits.SPIBUSY);
    id = ReadSPI2();
    GYRO_CS = 1;
    return (int)id;
}

float getGyro(INT16 axis) {
    INT8 low;
    INT8 high;
    float data;
    
    GYRO_CS = 0;
    while(TxBufFullSPI2());
    WriteSPI2(0xC0 | axis); // 11101000
    while (SPI2STATbits.SPIBUSY);
    ReadSPI2();
    WriteSPI2(0xFF);
    while (SPI2STATbits.SPIBUSY);
    low = ReadSPI2();
    WriteSPI2(0xFF);
    while (SPI2STATbits.SPIBUSY);
    high = ReadSPI2();
    GYRO_CS = 1;
    data =  (float)(low | (high << 8));
    
    switch(range)
    {
    case L3DS20_RANGE_250DPS:
        data *= L3GD20_SENSITIVITY_250DPS;
        break;
    case L3DS20_RANGE_500DPS:
        data *= L3GD20_SENSITIVITY_500DPS;
        break;
    case L3DS20_RANGE_2000DPS:
        data *= L3GD20_SENSITIVITY_2000DPS;
        break;
    }
    return data;
}

void writeGyroSpi(UINT8 addr, UINT8 data) {
    GYRO_CS = 0;
    while (TxBufFullSPI2());
    //or just combine this into two bytes - unsigned short
    WriteSPI2(addr & 0x7F); //binary AND with 01111111 (control byte) - 0 for write
    while (SPI2STATbits.SPIBUSY); // wait for it to end of transaction
    ReadSPI2();
    WriteSPI2(data);
    while (SPI2STATbits.SPIBUSY);
    ReadSPI2();
    GYRO_CS = 1;
}
