/* 
 * File:   gyro.h
 * Author: Matthew Magaldi
 *
 * Created on December 3, 2015, 4:57 PM
 */

#ifndef GYRO_H
#define	GYRO_H

/*=========================================================================
    MODE SETTINGS
    -----------------------------------------------------------------------*/
#define L3GD20_SENSITIVITY_250DPS  (0.00875F)      // Roughly 22/256 for fixed point match
#define L3GD20_SENSITIVITY_500DPS  (0.0175F)       // Roughly 45/256
#define L3GD20_SENSITIVITY_2000DPS (0.070F)        // Roughly 18/256
#define L3GD20_DPS_TO_RADS         (0.017453293F)  // degress/s to rad/s multiplier


/*=========================================================================
    REGISTERS
    -----------------------------------------------------------------------*/
#define WHOAMI          0x0F
#define CTRL1           0x20
#define CTRL2           0x21
#define CTRL3           0x22
#define CTRL4           0x23
#define CTRL5           0x24
#define REFERENCE       0x25
#define OUT_TEMP        0x26
#define STATUS          0x27
#define OUT_X           0x28
#define OUT_Y           0x2A
#define OUT_Z           0x2C
#define FIFO_CTRL       0x2E
#define FIFO_SRC        0x2F
#define LOW_ODR         0x39

/*=========================================================================
    PIN CONNECTIONS & VARIABLES
    -----------------------------------------------------------------------*/
typedef enum
{
    L3DS20_RANGE_250DPS,
    L3DS20_RANGE_500DPS,
    L3DS20_RANGE_2000DPS
} l3gd20Range_t;

//CHIP SELECT - RPB7
#define GYRO_CS         LATBbits.LATB5    //physical pin 14
#define GYRO_CS_dir     TRISBbits.TRISB5

#define PBCLK 40000000              // peripheral bus clock
#define SPI2_freq    2000000        // max is 10Mhz
#define dTimeMs PBCLK/1000          //check this to be right

static l3gd20Range_t range;


/*=========================================================================
    USER FUNCTIONS
    -----------------------------------------------------------------------*/
int begin_gyro(l3gd20Range_t);
int debug_gyro(void);
void writeGyroSpi(UINT8 , UINT8 );
float getGyro(INT16);

#endif	/* GYRO_H */

